@@ -1,19 +1,19 @@
 #' @title Fold change (\eqn{\Delta \Delta C_T} method) analysis using a model
 #' 
-#' @description Fold change (\eqn{\Delta \Delta C_T} method) analysis using a model produced by the
+#' @description Fold change (\eqn{\Delta \Delta C_T} method) analysis using a model object produced by the
 #' \code{qpcrANOVAFC} or \code{qpcrREPEATED}.
 #' 
-#' @details The \code{qpcrMeans} performs fold change (\eqn{\Delta \Delta C_T} method) analysis using a model produced by the
+#' @details The \code{qpcrMeans} function performs fold change (\eqn{\Delta \Delta C_T} method) analysis using a model produced by the
 #' \code{qpcrANOVAFC} or \code{qpcrREPEATED}. The values can be returned for any effects in the model including simple effects,
 #' interactions and slicing if an ANOVA model is used, but ANCOVA models returned by rtpcr package only include simple effects.
 #' 
 #' @author Ghader Mirzaghaderi
 #' @export qpcrMeans
 #' @import emmeans
-#' @param model an `lmer` fitted model object
+#' @param model an `lmer` fitted model object created by qpcrANOVAFC or qpcrREPEATED functions
 #' @param specs A character vector specifying the names of the predictors over which FC values are desired
 #' @param p.adj Method for adjusting p values
-#' @return Table of FC values, significance and confidence limits.
+#' @return Table of FC values, significance and confidence interval.
 #' 
 #' 
 #' @examples
@@ -21,7 +21,7 @@
 #' # Returning fold change values from a fitted model.
 #' # Firstly, result of `qpcrANOVAFC` or `qpcrREPEATED` is 
 #' # acquired which includes a model object:
-#' res <- qpcrANOVAFC(data_3factor, numberOfrefGenes = 1, mainFactor.column = 1)
+#' res <- qpcrANOVAFC(data_3factor, numberOfrefGenes = 1, mainFactor.column = 1, block = NULL)
 #' 
 #' # Returning fold change values of Type levels from a fitted model:
 #' qpcrMeans(res$lm_ANOVA, specs = "Type")
@@ -40,6 +40,11 @@
 
 
 qpcrMeans <- function(model, specs, p.adj = "none"){
+  
+  if(any(c("lmerModLmerTest", "lm") %in% class(model)) == FALSE){
+    stop(deparse(substitute(model)), " is not an accepted model object created by qpcrANOVAFC, qpcrANOVARE, or qpcrREPEATED functions!")
+  }
+  
   f <- stats::as.formula(paste("pairwise ~", specs))
   base::suppressMessages(Pv <- emmeans(model, f, adjust = p.adj))
   base::suppressMessages(emm2 <- stats::confint(emmeans(model, f, adjust = p.adj)))
